@@ -3,9 +3,6 @@ from gaphor.RAAML.stpa.operationalsituation import OperationalSituationItem
 from gaphor.RAAML.stpa.relationships import RelevantToItem
 from gaphor.RAAML.stpa.unsafecontrolaction import UnsafeControlActionItem
 
-# This need to be imported after RelevantToItem
-import gaphor.RAAML.stpa.connectors
-
 __all__ = [
     "ControlActionItem",
     "OperationalSituationItem",
