@@ -3,7 +3,11 @@ from gaphor.RAAML import raaml
 from gaphor.SysML.requirements.relationships import DirectedRelationshipPropertyPathItem
 
 
-@represents(raaml.RelevantTo)
+@represents(
+    raaml.RelevantTo,
+    head=raaml.RelevantTo.sourceContext,
+    tail=raaml.RelevantTo.targetContext,
+)
 class RelevantToItem(DirectedRelationshipPropertyPathItem):
 
     relation_type = "relevantTo"
