@@ -3,13 +3,15 @@
 from gaphor import UML
 from gaphor.core import gettext
 from gaphor.diagram.diagramtoolbox import (
+    DiagramType,
+    DiagramTypes,
     ToolboxDefinition,
     ToolDef,
     ToolSection,
     general_tools,
     namespace_config,
+    new_item_factory,
 )
-from gaphor.diagram.tools import new_item_factory
 from gaphor.SysML import diagramitems as sysml_items
 from gaphor.SysML.blocks.blockstoolbox import blocks
 from gaphor.SysML.requirements.requirementstoolbox import requirements
@@ -59,3 +61,16 @@ sysml_toolbox_actions: ToolboxDefinition = (
     states,
     use_cases,
 )
+
+
+# Not implemented: Parameter Diagram
+sysml_diagram_types: DiagramTypes = (
+    DiagramType("bdd", gettext("New Block Definition Diagram"), (blocks,)),
+    DiagramType("ibd", gettext("New Internal Block Diagram"), (internal_blocks,)),
+    DiagramType("pkg", gettext("New Package Diagram"), (blocks,)),
+    DiagramType("req", gettext("New Requirement Diagram"), (requirements,)),
+    DiagramType("act", gettext("New Activity Diagram"), (actions,)),
+    DiagramType("sd", gettext("New Sequence Diagram"), (interactions,)),
+    DiagramType("stm", gettext("New State Machine Diagram"), (states,)),
+    DiagramType("uc", gettext("New Use Case Diagram"), (use_cases,)),
+)
