@@ -2,4 +2,6 @@
 import gaphor.UML.umloverrides
 from gaphor.UML.uml import *
 import gaphor.UML.deletable
+import gaphor.UML.drop
 import gaphor.UML.iconname
+import gaphor.UML.group
