@@ -1,16 +1,20 @@
 from gaphor.UML.actions import (
     actionseditors,
-    actionsgrouping,
+    actionsgroup,
     actionspropertypages,
+    activityconnect,
+    activitypropertypage,
     copypaste,
     flowconnect,
     partitionpage,
+    pinconnect,
 )
 from gaphor.UML.actions.action import (
     AcceptEventActionItem,
     ActionItem,
     SendSignalActionItem,
 )
+from gaphor.UML.actions.activity import ActivityItem, ActivityParameterNodeItem
 from gaphor.UML.actions.activitynodes import (
     ActivityFinalNodeItem,
     ActivityNodeItem,
@@ -19,13 +23,17 @@ from gaphor.UML.actions.activitynodes import (
     ForkNodeItem,
     InitialNodeItem,
 )
-from gaphor.UML.actions.flow import FlowItem
+from gaphor.UML.actions.flow import ControlFlowItem, ObjectFlowItem
 from gaphor.UML.actions.objectnode import ObjectNodeItem
 from gaphor.UML.actions.partition import PartitionItem
+from gaphor.UML.actions.pin import InputPinItem, OutputPinItem
+
 
 __all__ = [
     "AcceptEventActionItem",
     "ActionItem",
+    "ActivityItem",
+    "ActivityParameterNodeItem",
     "SendSignalActionItem",
     "ActivityFinalNodeItem",
     "ActivityNodeItem",
@@ -33,7 +41,10 @@ __all__ = [
     "FlowFinalNodeItem",
     "ForkNodeItem",
     "InitialNodeItem",
-    "FlowItem",
+    "InputPinItem",
+    "ControlFlowItem",
+    "ObjectFlowItem",
     "ObjectNodeItem",
+    "OutputPinItem",
     "PartitionItem",
 ]
