@@ -5,7 +5,12 @@ from gaphas.item import SE
 
 from gaphor import UML
 from gaphor.core import gettext
-from gaphor.diagram.diagramtoolbox import ToolDef, ToolSection, new_item_factory
+from gaphor.diagram.diagramtoolbox import (
+    ToolDef,
+    ToolSection,
+    namespace_config,
+    new_item_factory,
+)
 from gaphor.UML import diagramitems
 from gaphor.UML.recipes import owner_package
 
@@ -51,6 +56,18 @@ def partition_config(new_item):
 actions = ToolSection(
     gettext("Actions"),
     (
+        ToolDef(
+            "toolbox-activity",
+            gettext("Activity"),
+            "gaphor-activity-symbolic",
+            None,
+            new_item_factory(
+                diagramitems.ActivityItem,
+                UML.Activity,
+                config_func=namespace_config,
+            ),
+            handle_index=SE,
+        ),
         ToolDef(
             "toolbox-action",
             gettext("Action"),
@@ -148,11 +165,18 @@ actions = ToolSection(
             handle_index=SE,
         ),
         ToolDef(
-            "toolbox-flow",
-            gettext("Control/object flow"),
+            "toolbox-control-flow",
+            gettext("Control flow"),
             "gaphor-control-flow-symbolic",
             "<Shift>F",
-            new_item_factory(diagramitems.FlowItem),
+            new_item_factory(diagramitems.ControlFlowItem),
+        ),
+        ToolDef(
+            "toolbox-object-flow",
+            gettext("Object flow"),
+            "gaphor-object-flow-symbolic",
+            "<Shift>Y",
+            new_item_factory(diagramitems.ObjectFlowItem),
         ),
         ToolDef(
             "toolbox-send-signal-action",
@@ -178,5 +202,19 @@ actions = ToolSection(
             ),
             handle_index=SE,
         ),
+        ToolDef(
+            "toolbox-input-pin",
+            gettext("Input pin"),
+            "gaphor-input-pin-symbolic",
+            None,
+            new_item_factory(diagramitems.InputPinItem),
+        ),
+        ToolDef(
+            "toolbox-output-pin",
+            gettext("Output pin"),
+            "gaphor-output-pin-symbolic",
+            None,
+            new_item_factory(diagramitems.OutputPinItem),
+        ),
     ),
 )
