@@ -2,6 +2,7 @@ from gi.repository import Gtk
 
 from gaphor import UML
 from gaphor.core.format import format
+from gaphor.diagram.hoversupport import widget_add_hover_support
 from gaphor.diagram.propertypages import (
     PropertyPageBase,
     PropertyPages,
@@ -39,13 +40,18 @@ class EnumerationPage(PropertyPageBase):
 
         builder = new_builder(
             "enumerations-editor",
+            "enumerations-info",
             signals={
                 "show-enumerations-changed": (self._on_show_enumerations_change,),
                 "enumerations-name-edited": (on_text_cell_edited, self.model, 0),
                 "tree-view-destroy": (self.watcher.unsubscribe_all,),
+                "enumerations-info-clicked": (self.on_enumerations_info_clicked),
             },
         )
 
+        self.info = builder.get_object("enumerations-info")
+        widget_add_hover_support(builder.get_object("enumerations-info-icon"))
+
         show_enumerations = builder.get_object("show-enumerations")
         show_enumerations.set_active(self.item.show_enumerations)
 
@@ -74,6 +80,9 @@ class EnumerationPage(PropertyPageBase):
         self.item.show_enumerations = button.get_active()
         self.item.request_update()
 
+    def on_enumerations_info_clicked(self, image, event):
+        self.info.show()
+
 
 PropertyPages.register(EnumerationItem)(AttributesPage)
 PropertyPages.register(EnumerationItem)(OperationsPage)
