@@ -59,7 +59,7 @@ PI_2 = pi / 2
 
 
 @represents(UML.Message)
-class MessageItem(LinePresentation[UML.Message], Named):
+class MessageItem(Named, LinePresentation[UML.Message]):
     """Message item is drawn on sequence and communication diagrams.
 
     On communication diagram, message item is decorated with an arrow in
@@ -181,13 +181,7 @@ class MessageItem(LinePresentation[UML.Message], Named):
         with cairo_state(cr):
             angle: float = self._arrow_angle
 
-            hint = -1
-
-            # rotation hint, keep arrow on the same side as message text
-            # elements
-            if abs(angle) >= PI_2 and angle != -PI_2:
-                hint = 1
-
+            hint = 1 if abs(angle) >= PI_2 and angle != -PI_2 else -1
             if inverted:
                 angle += hint * pi
 
