@@ -11,7 +11,7 @@ from gaphor.UML.states.state import VertexItem
 
 
 @represents(UML.FinalState)
-class FinalStateItem(ElementPresentation, VertexItem):
+class FinalStateItem(VertexItem, ElementPresentation):
     def __init__(self, diagram, id=None):
         super().__init__(diagram, id, width=30, height=30)
         for h in self.handles():
@@ -39,8 +39,7 @@ def draw_final_state(box, context, bounding_box):
     cr.set_line_width(2)
     stroke(context)
 
-    stroke_color = context.style["color"]
-    if stroke_color:
+    if stroke_color := context.style["color"]:
         cr.set_source_rgba(*stroke_color)
 
     d = 20
