@@ -7,8 +7,8 @@ from gaphor.diagram.support import represents
 from gaphor.UML.recipes import stereotypes_str
 
 
-@represents(UML.Transition)
-class TransitionItem(LinePresentation[UML.Transition], Named):
+@represents(UML.Transition, head=UML.Transition.source, tail=UML.Transition.target)
+class TransitionItem(Named, LinePresentation[UML.Transition]):
     """Representation of state transition."""
 
     def __init__(self, diagram, id=None):
