@@ -62,8 +62,8 @@ def property_navigability(self: uml.Property) -> list[bool | None]:
         return [None]  # assume unknown
     owner = self.opposite.type
     if (
-        isinstance(owner, (uml.Class, uml.Interface))
-        and isinstance(self.type, (uml.Class, uml.Interface))
+        isinstance(owner, (uml.Class, uml.DataType, uml.Interface))
+        and isinstance(self.type, (uml.Class, uml.DataType, uml.Interface))
         and (self in owner.ownedAttribute)
         or self in assoc.navigableOwnedEnd
     ):
@@ -139,9 +139,7 @@ def message_messageKind(self) -> str:
     """MessageKind."""
     kind = "unknown"
     if self.sendEvent:
-        kind = "lost"
-        if self.receiveEvent:
-            kind = "complete"
+        kind = "complete" if self.receiveEvent else "lost"
     elif self.receiveEvent:
         kind = "found"
     return kind
