@@ -8,8 +8,8 @@ from gaphor.diagram.support import represents
 from gaphor.UML.recipes import stereotypes_str
 
 
-@represents(UML.Include)
-class IncludeItem(LinePresentation, Named):
+@represents(UML.Include, head=UML.Include.addition, tail=UML.Include.includingCase)
+class IncludeItem(Named, LinePresentation):
     """Use case inclusion relationship."""
 
     def __init__(self, diagram, id=None):
