@@ -4,8 +4,8 @@
 from __future__ import annotations
 
 import logging
-import uuid
 from typing import TYPE_CHECKING, Callable, Iterator, Protocol, TypeVar, overload
+from uuid import uuid1
 
 from gaphor.core.modeling.event import ElementUpdated
 from gaphor.core.modeling.properties import (
@@ -36,18 +36,47 @@ class UnlinkEvent:
 Id = str
 
 
+def uuid_generator():
+    while True:
+        yield str(uuid1())
+
+
+_generator: Iterator[str] = uuid_generator()
+
+
+def generate_id(generator=None):
+    global _generator
+    if generator:
+        _generator = generator
+    return next(_generator)
+
+
+def self_and_owners(element: Element | None) -> Iterator[Element]:
+    """Return the element and the ancestors (Element.owner)."""
+    seen = set()
+    e = element
+    while e:
+        if e in seen:
+            return
+        yield e
+        seen.add(e)
+        e = e.owner
+
+
 class Element:
     """Base class for all model data classes."""
 
     note: attribute[str] = attribute("note", str)
-    appliedStereotype: relation_many[Element]
     comment: relation_many[Comment]
-    directedRelationship: relation_many[Presentation]
+    ownedDiagram: relation_many[Diagram]
     ownedElement: relation_many[Element]
     owner: relation_one[Element]
     presentation: relation_many[Presentation]
-    relationship: relation_many[Presentation]
-    ownedDiagram: relation_many[Diagram]
+
+    # From UML:
+    directedRelationship: relation_many[Element]
+    relationship: relation_many[Element]
+    appliedStereotype: relation_many[Element]
 
     def __init__(self, id: Id | None = None, model: RepositoryProtocol | None = None):
         """Create an element. As optional parameters an id and model can be
@@ -59,7 +88,7 @@ class Element:
 
         A model can be provided to refer to the model this element belongs to.
         """
-        self._id: Id = id or str(uuid.uuid1())
+        self._id: Id = id or generate_id()
         # The model this element belongs to.
         self._model = model
         self._unlink_lock = 0
@@ -78,12 +107,12 @@ class Element:
         return self._model
 
     @classmethod
-    def umlproperties(class_) -> Iterator[umlproperty]:
+    def umlproperties(cls) -> Iterator[umlproperty]:
         """Iterate over all properties."""
         umlprop = umlproperty
-        for propname in dir(class_):
+        for propname in dir(cls):
             if not propname.startswith("_"):
-                prop = getattr(class_, propname)
+                prop = getattr(cls, propname)
                 if isinstance(prop, umlprop):
                     yield prop
 
@@ -116,33 +145,31 @@ class Element:
         The unlink lock is acquired while unlinking this elements
         properties to avoid recursion problems.
         """
-        self.inner_unlink(UnlinkEvent(self))
-
-    def inner_unlink(self, unlink_event):
         if self._unlink_lock:
             return
 
+        self._unlink_lock += 1
+
         try:
-            self._unlink_lock += 1
-
-            for prop in self.umlproperties():
-                prop.unlink(self)
-
-            log.debug("unlinking %s", self)
-            self.handle(unlink_event)
-            self._model = None
+            self.inner_unlink(UnlinkEvent(self))
         finally:
             self._unlink_lock -= 1
 
+    def inner_unlink(self, unlink_event: UnlinkEvent):
+        for prop in self.umlproperties():
+            prop.unlink(self)
+
+        log.debug("unlinking %s", self)
+        self.handle(unlink_event or UnlinkEvent(self))
+        self._model = None
+
     def handle(self, event):
         """Propagate incoming events."""
-        model = self._model
-        if model:
+        if model := self._model:
             model.handle(event)
 
     def watcher(self, default_handler: Handler | None = None) -> EventWatcherProtocol:
-        model = self._model
-        if model:
+        if model := self._model:
             return model.watcher(self, default_handler)
         else:
             return DummyEventWatcher()
