@@ -6,7 +6,9 @@ gaphor.adapter package.
 
 from __future__ import annotations
 
-from typing import Protocol, TypeVar
+import functools
+import itertools
+from typing import Iterator, Protocol, TypeVar
 
 from gaphas.connections import Connection
 from gaphas.connector import Handle, Port
@@ -14,7 +16,9 @@ from generic.multidispatch import FunctionDispatcher, multidispatch
 
 from gaphor.core.modeling import Diagram, Element, Presentation
 from gaphor.core.modeling.properties import association, redefine, relation
+from gaphor.diagram.copypaste import copy, paste
 from gaphor.diagram.presentation import ElementPresentation, LinePresentation
+from gaphor.diagram.support import get_diagram_item_metadata, get_model_element
 
 T = TypeVar("T", bound=Element)
 
@@ -22,8 +26,8 @@ T = TypeVar("T", bound=Element)
 class ConnectorProtocol(Protocol):
     def __init__(
         self,
-        element: object,
-        line: object,
+        element: Presentation,
+        line: Presentation,
     ) -> None:
         ...
 
@@ -54,7 +58,6 @@ class BaseConnector:
       disconnects, if required (e.g. 1:1 relationships)
     - ``disconnect()``: Break connection, called when dropping a handle on a
       point where it can not connect.
-    - ``reconnect()`` (*Optional*): Connect to another item (only used if present)
 
     By convention the adapters are registered by (element, line) -- in that order.
     """
@@ -66,19 +69,14 @@ class BaseConnector:
     ) -> None:
         assert (
             element.diagram and element.diagram is line.diagram
-        ), f"Connector without diagram ({element}: {element.diagram}, {line}: {line.diagram})"
+        ), f"Cannot connect with different diagrams ({element}: {element.diagram}, {line}: {line.diagram})"
         self.element = element
         self.line = line
         self.diagram: Diagram = element.diagram
 
-    def get_connection(self, handle: Handle) -> Connection | None:
-        """Get connection information."""
-        return self.diagram.connections.get_connection(handle)
-
     def get_connected(self, handle: Handle) -> Presentation[Element] | None:
         """Get item connected to a handle."""
-        cinfo = self.diagram.connections.get_connection(handle)
-        if cinfo:
+        if cinfo := self.diagram.connections.get_connection(handle):
             return cinfo.connected  # type: ignore[no-any-return] # noqa: F723
         return None
 
@@ -127,13 +125,23 @@ Connector: FunctionDispatcher[type[ConnectorProtocol]] = multidispatch(object, o
 )
 
 
-class UnaryRelationshipConnect(BaseConnector):
+@functools.lru_cache()
+def can_connect(parent, element_type) -> bool:
+    parent_type = type(parent)
+    get_registration = Connector.registry.get_registration
+    for t1, t2 in itertools.product(parent_type.__mro__, element_type.__mro__):
+        if r := get_registration(t1, t2):
+            return r is not NoConnector
+    return False
+
+
+class RelationshipConnect(BaseConnector):
     """Base class for relationship connections, such as associations,
     dependencies and implementations.
 
-    Unary relationships are allowed to connect both ends to the same element
+    Unary relationships are allowed to connect both ends to the same element.
 
-    This class introduces a new method: relationship() which is used to
+    This class introduces a new method: `relationship()`, which is used to
     find an existing relationship in the model that does not yet exist
     on the diagram.
     """
@@ -141,9 +149,15 @@ class UnaryRelationshipConnect(BaseConnector):
     element: Presentation
     line: LinePresentation[Element]
 
+    def __init__(
+        self, element: Presentation[Element], line: Presentation[Element]
+    ) -> None:
+        super().__init__(element, line)
+        self.copy_buffer = dict(copy(line.subject)) if line.subject else {}
+
     def relationship(
-        self, required_type: type[Element], head: relation, tail: relation
-    ) -> Element | None:
+        self, required_type: type[T], head: relation, tail: relation
+    ) -> T | None:
         """Find an existing relationship in the model that meets the required
         type and is connected to the same model element the head and tail of
         the line are connected to.
@@ -152,6 +166,9 @@ class UnaryRelationshipConnect(BaseConnector):
         head - tuple (association name on line, association name on element)
         tail - tuple (association name on line, association name on element)
         """
+        assert isinstance(head, (association, redefine)), f"head is {head}"
+        assert isinstance(tail, (association, redefine)), f"tail is {tail}"
+
         line = self.line
 
         line_head = self.get_connected(line.head)
@@ -164,13 +181,10 @@ class UnaryRelationshipConnect(BaseConnector):
         # First check if the right subject is already connected:
         if (
             line.subject
-            and getattr(line.subject, head.name) is head_subject
-            and getattr(line.subject, tail.name) is tail_subject
+            and head.get(line.subject) is head_subject
+            and tail.get(line.subject) is tail_subject
         ):
-            return line.subject
-
-        assert isinstance(head, (association, redefine)), f"head is {head}"
-        assert isinstance(tail, (association, redefine)), f"tail is {tail}"
+            return line.subject  # type: ignore[return-value]
 
         # Try to find a relationship, that is already created, but not
         # yet displayed in the diagram on the tail side, since tail should
@@ -183,7 +197,7 @@ class UnaryRelationshipConnect(BaseConnector):
             if not isinstance(gen, required_type):
                 continue
 
-            gen_head = getattr(gen, head.name)
+            gen_head = head.get(gen)
             try:
                 if head_subject not in gen_head:
                     continue
@@ -202,46 +216,44 @@ class UnaryRelationshipConnect(BaseConnector):
                 return gen
         return None
 
+    def new_relation(self, type: type[T]) -> T:
+        return self.line.model.create(type)
+
+    def new_relation_from_copy(self, type: type[T]) -> T | None:
+        if not self.copy_buffer:
+            return None
+
+        for e in paste_model(self.copy_buffer, self.diagram):
+            if isinstance(e, type):
+                return e
+
+        raise AssertionError(
+            f"Copied elements, but no {type} found ({self.copy_buffer})"
+        )
+
     def relationship_or_new(self, type: type[T], head: relation, tail: relation) -> T:
         """Like relation(), but create a new instance if none was found."""
         relation = self.relationship(type, head, tail)
+        if relation:
+            return relation
+
+        line = self.line
+        relation = self.new_relation_from_copy(type)
         if not relation:
-            line = self.line
-            relation = line.model.create(type)
-            line_head = self.get_connected(line.head)
-            line_tail = self.get_connected(line.tail)
-            assert line_head
-            assert line_tail
-            setattr(relation, head.name, line_head.subject)
-            setattr(relation, tail.name, line_tail.subject)
+            relation = self.new_relation(type)
+
+        assert isinstance(relation, type)
+        line_head = self.get_connected(line.head)
+        line_tail = self.get_connected(line.tail)
+
+        assert line_head
+        assert line_tail
+        head.set(relation, line_head.subject)
+        tail.set(relation, line_tail.subject)
+
         assert isinstance(relation, type)
         return relation
 
-    def reconnect_relationship(
-        self, handle: Handle, head: relation, tail: relation
-    ) -> None:
-        """Reconnect relationship for given handle.
-
-        :Parameters:
-         handle
-            Handle at which reconnection happens.
-         head
-            Relationship head attribute name.
-         tail
-            Relationship tail attribute name.
-        """
-        line = self.line
-        c1 = self.get_connected(line.head)
-        c2 = self.get_connected(line.tail)
-        assert c1
-        assert c2
-        if line.head is handle:
-            setattr(line.subject, head.name, c1.subject)
-        elif line.tail is handle:
-            setattr(line.subject, tail.name, c2.subject)
-        else:
-            raise ValueError("Incorrect handle passed to adapter")
-
     def connect_connected_items(self, connections: None = None) -> None:
         """Cause items connected to ``line`` to reconnect, allowing them to
         establish or destroy relationships at model level."""
@@ -254,9 +266,7 @@ class UnaryRelationshipConnect(BaseConnector):
             if line is cinfo.connected:
                 continue
             adapter = Connector(line, cinfo.connected)
-            assert adapter, "No element to connect {} and {}".format(
-                line, cinfo.connected
-            )
+            assert adapter, f"No element to connect {line} and {cinfo.connected}"
             adapter.connect(cinfo.handle, cinfo.port)
 
     def disconnect_connected_items(self) -> list[Connection]:
@@ -302,8 +312,7 @@ class UnaryRelationshipConnect(BaseConnector):
         if not super().connect(handle, port):
             return False
         opposite = self.line.opposite(handle)
-        oct = self.get_connected(opposite)
-        if oct:
+        if self.get_connected(opposite):
             self.connect_subject(handle)
             line = self.line
             if line.subject:
@@ -325,7 +334,7 @@ class UnaryRelationshipConnect(BaseConnector):
         super().disconnect(handle)
 
 
-class RelationshipConnect(UnaryRelationshipConnect):
+class DirectionalRelationshipConnect(RelationshipConnect):
     """Base for relationship connections between unique elements."""
 
     def allow(self, handle: Handle, port: Port) -> bool:
@@ -352,3 +361,67 @@ class RelationshipConnect(UnaryRelationshipConnect):
             return False
 
         return super().allow(handle, port)
+
+
+@Connector.register(ElementPresentation, LinePresentation)
+class MetadataRelationConnect(DirectionalRelationshipConnect):
+    """A generic relationship connector."""
+
+    def allow(self, handle, port):
+        if not super().allow(handle, port):
+            return False
+
+        element = self.element
+        opposite_element = self.get_connected(self.line.opposite(handle))
+        metadata = get_diagram_item_metadata(type(self.line))
+
+        if not metadata:
+            return False
+
+        if handle is self.line.head:
+            return isinstance(element.subject, metadata["head"].type) and (
+                not opposite_element
+                or isinstance(opposite_element.subject, metadata["tail"].type)
+            )
+        else:
+            return isinstance(element.subject, metadata["tail"].type) and (
+                not opposite_element
+                or isinstance(opposite_element.subject, metadata["head"].type)
+            )
+
+    def connect_subject(self, handle):
+        subject_type = get_model_element(type(self.line))
+        metadata = get_diagram_item_metadata(type(self.line))
+        if not metadata:
+            return False
+
+        self.line.subject = self.relationship_or_new(
+            subject_type, metadata["head"], metadata["tail"]
+        )
+        return True
+
+
+def paste_model(copy_data, diagram) -> Iterator[Element]:
+
+    new_elements: dict[str, Element] = {}
+
+    def create(ref: str):
+        if ref in new_elements:
+            return new_elements[ref]
+
+        if ref in copy_data:
+            paster = paste(copy_data[ref], diagram, create)
+            new_elements[ref] = next(paster)
+            next(paster, None)
+            return new_elements[ref]
+
+    for old_id in copy_data:
+        if old_id in new_elements:
+            continue
+        create(old_id)
+
+    for element in new_elements.values():
+        assert element
+        element.postload()
+
+    return iter(new_elements.values())
