@@ -31,17 +31,16 @@ class Box(ElementPresentation):
 
 
 class Ellipse(ElementPresentation):
-    """"""
-
     def __init__(self, diagram, id=None):
         super().__init__(diagram=diagram, id=id)
 
     def draw(self, context):
         cr = context.cairo
 
+        x, y = self.handles()[0].pos
         rx = self.width / 2.0
         ry = self.height / 2.0
 
-        cr.move_to(self.width, ry)
-        path_ellipse(cr, rx, ry, self.width, self.height)
+        cr.move_to(x + self.width, y + ry)
+        path_ellipse(cr, x + rx, y + ry, self.width, self.height)
         stroke(context)
