@@ -7,7 +7,8 @@ from math import atan2
 import gaphas
 from gaphas.connector import ConnectionSink
 from gaphas.connector import Connector as ConnectorAspect
-from gaphas.connector import Handle
+from gaphas.connector import Handle, LinePort, Position
+from gaphas.constraint import constraint
 from gaphas.geometry import Rectangle, distance_rectangle_point
 from gaphas.solver.constraint import BaseConstraint
 
@@ -52,6 +53,12 @@ def from_package_str(item):
     )
 
 
+def connect(item: gaphas.Item, handle: gaphas.Handle, target: gaphas.Item):
+    connector = ConnectorAspect(item, handle, item.diagram.connections)
+    sink = ConnectionSink(target, distance=1e40)
+    connector.connect(sink)
+
+
 def postload_connect(item: gaphas.Item, handle: gaphas.Handle, target: gaphas.Item):
     """Helper function: when loading a model, handles should be connected as
     part of the `postload` step.
@@ -59,9 +66,8 @@ def postload_connect(item: gaphas.Item, handle: gaphas.Handle, target: gaphas.It
     This function finds a suitable spot on the `target` item to connect
     the handle to.
     """
-    connector = ConnectorAspect(item, handle, item.diagram.connections)
-    sink = ConnectionSink(target, distance=1e4)
-    connector.connect(sink)
+    target.postload()
+    connect(item, handle, target)
 
 
 class HandlePositionEvent(RevertibeEvent):
@@ -150,12 +156,19 @@ class ElementPresentation(gaphas.Element, HandlePositionUpdate, Presentation[S])
 
     def save(self, save_func):
         save_func("matrix", tuple(self.matrix))
+        save_func("top-left", tuple(map(float, self._handles[0].pos)))
         save_func("width", self.width)
         save_func("height", self.height)
         super().save(save_func)
 
     def load(self, name, value):
-        if name == "width":
+        if name == "top-left":
+            pos = ast.literal_eval(value)
+            self._handles[0].pos = pos
+            # Also adjust bottom-right handle to keep width and height intact
+            self._handles[2].pos.x += pos[0]
+            self._handles[2].pos.y += pos[1]
+        elif name == "width":
             self.width = ast.literal_eval(value)
         elif name == "height":
             self.height = ast.literal_eval(value)
@@ -251,17 +264,6 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
         return min(d0, *ds) if ds else d0
 
     def draw(self, context):
-        def draw_line_end(end_handle, second_handle, draw):
-            pos, p1 = end_handle.pos, second_handle.pos
-            angle = atan2(p1.y - pos.y, p1.x - pos.x)
-            cr.save()
-            try:
-                cr.translate(*pos)
-                cr.rotate(angle)
-                draw(context)
-            finally:
-                cr.restore()
-
         style = merge_styles(context.style, self.style)
         context = replace(context, style=style)
 
@@ -269,12 +271,12 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
         cr = context.cairo
 
         handles = self._handles
-        draw_line_end(handles[0], handles[1], self.draw_head)
+        draw_line_end(context, handles[0], handles[1], self.draw_head)
 
         for h in self._handles[1:-1]:
             cr.line_to(*h.pos)
 
-        draw_line_end(handles[-1], handles[-2], self.draw_tail)
+        draw_line_end(context, handles[-1], handles[-2], self.draw_tail)
 
         stroke(context)
 
@@ -288,8 +290,7 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
 
     def save(self, save_func):
         def save_connection(name, handle):
-            c = self._connections.get_connection(handle)
-            if c:
+            if c := self._connections.get_connection(handle):
                 save_func(name, c.connected)
 
         super().save(save_func)
@@ -340,3 +341,183 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
 
     def _on_horizontal(self, _event):
         self.update_orthogonal_constraints(self.orthogonal)
+
+
+def draw_line_end(context, end_handle, second_handle, draw):
+    cr = context.cairo
+    pos, p1 = end_handle.pos, second_handle.pos
+    angle = atan2(p1.y - pos.y, p1.x - pos.x)
+    cr.save()
+    try:
+        cr.translate(*pos)
+        cr.rotate(angle)
+        draw(context)
+    finally:
+        cr.restore()
+
+
+class AttachedPresentation(HandlePositionUpdate, Presentation[S]):
+    """An attached presentation is a base type for all sorts of element-like
+    presentations that can be attached to an element.
+
+    An AttachedPresentation has one handle at the center to connect to
+    an element.
+
+    E.g. ports, pins and parameter nodes.
+    """
+
+    def __init__(self, diagram, id=None, width=16, height=16):
+        super().__init__(diagram, id)
+        self._connections = diagram.connections
+        self._width_constraints = []
+        self._height_constraints = []
+
+        handle = self._handle = Handle(strength=gaphas.solver.STRONG, connectable=True)
+        self.watch_handle(handle)
+
+        rh = width / 2
+        rv = height / 2
+        top_left = Position(-rh, -rv)
+        top_right = Position(rh, -rv)
+        bottom_right = Position(rh, rv)
+        bottom_left = Position(-rh, rv)
+
+        add = diagram.connections.add_constraint
+        add(self, constraint(horizontal=(top_left, top_right)))
+        add(self, constraint(horizontal=(bottom_left, bottom_right)))
+        add(self, constraint(vertical=(top_left, bottom_left)))
+        add(self, constraint(vertical=(top_right, bottom_right)))
+
+        self._corners = [top_left, top_right, bottom_right, bottom_left]
+
+        self._ports = [
+            LinePort(top_left, top_right),
+            LinePort(top_right, bottom_right),
+            LinePort(bottom_right, bottom_left),
+            LinePort(bottom_left, top_left),
+        ]
+
+        self.width = width
+        self.height = height
+
+        self._shape = None
+        self._last_connected_side = None
+
+    @property
+    def width(self) -> float:
+        c = self._corners
+        return float(c[2].x) - float(c[0].x)
+
+    @width.setter
+    def width(self, width):
+        self.update_width(width)
+
+    def update_width(self, width, factor=0.5):
+        rv = width * factor
+        top_left, _, bottom_right, _ = self._corners
+        handle_pos = self._handle.pos
+        connections = self._connections
+        for c in self._width_constraints:
+            connections.remove_constraint(self, c)
+
+        self._width_constraints = [
+            constraint(vertical=(top_left, handle_pos), delta=width - rv),
+            constraint(vertical=(handle_pos, bottom_right), delta=rv),
+        ]
+
+        for c in self._width_constraints:
+            connections.add_constraint(self, c)
+        self.request_update()
+
+    @property
+    def height(self) -> float:
+        c = self._corners
+        return float(c[2].y) - float(c[0].y)
+
+    @height.setter
+    def height(self, height):
+        self.update_height(height)
+
+    def update_height(self, height, factor=0.5):
+        rh = height * factor
+        top_left, _, bottom_right, _ = self._corners
+        handle_pos = self._handle.pos
+        connections = self._connections
+        for c in self._height_constraints:
+            connections.remove_constraint(self, c)
+
+        self._height_constraints = [
+            constraint(horizontal=(top_left, handle_pos), delta=height - rh),
+            constraint(horizontal=(handle_pos, bottom_right), delta=rh),
+        ]
+
+        for c in self._height_constraints:
+            connections.add_constraint(self, c)
+        self.request_update()
+
+    @property
+    def shape(self):
+        return self._shape
+
+    @shape.setter
+    def shape(self, shape) -> None:
+        self._shape = shape
+        self.request_update()
+
+    def handles(self):
+        return [self._handle]
+
+    def ports(self):
+        return self._ports
+
+    def update_shapes(self, event=None):
+        """Updating the shape configuration, e.g. when extra elements have to
+        be drawn or when styling changes."""
+
+    def update(self, context):
+        side = self.connected_side()
+        if not self.shape or self._last_connected_side != side:
+            self._last_connected_side = side
+            self.update_shapes()
+
+        self.shape.size(context)
+
+    def connected_side(self) -> str | None:
+        cinfo = self._connections.get_connection(self._handle)
+        return cinfo.connected.port_side(cinfo.port) if cinfo else None
+
+    def point(self, x, y):
+        return distance_rectangle_point(self.dimensions(), (x, y))
+
+    def draw(self, context):
+        self.shape.draw(context, self.dimensions())
+
+    def dimensions(self):
+        top_left, _, bottom_right, _ = self._corners
+        return Rectangle(top_left.x, top_left.y, x1=bottom_right.x, y1=bottom_right.y)
+
+    def save(self, save_func):
+        save_func("matrix", tuple(self.matrix))
+        save_func("point", tuple(map(float, self._handle.pos)))
+
+        if c := self._connections.get_connection(self._handle):
+            save_func("connection", c.connected)
+
+        super().save(save_func)
+
+    def load(self, name, value):
+        if name == "point":
+            self._handle.pos = ast.literal_eval(value)
+        elif name == "connection":
+            self._load_connection = value
+        else:
+            super().load(name, value)
+
+    def postload(self):
+        super().postload()
+        if hasattr(self, "_load_connection"):
+            postload_connect(self, self._handle, self._load_connection)
+            del self._load_connection
+
+        self.update_shapes()
+        self._connections.solve()
