@@ -36,11 +36,18 @@ class ApplicationShutdown(ServiceEvent):
 class SessionCreated(ServiceEvent):
     """The session is emitting this event when it's ready to shut down."""
 
-    def __init__(self, applicaton: Service, session: Service, filename: Optional[str]):
+    def __init__(
+        self,
+        applicaton: Service,
+        session: Service,
+        filename: Optional[str],
+        template: Optional[str],
+    ):
         super().__init__(applicaton)
         self.application = applicaton
         self.session = session
         self.filename = filename
+        self.template = template
 
 
 class ActiveSessionChanged(ServiceEvent):
@@ -98,3 +105,10 @@ class ActionEnabled:
             action_name.split(".", 2) if "." in action_name else ("win", action_name)
         )
         self.enabled = bool(enabled)
+
+
+class Notification:
+    """Inform the user about important events."""
+
+    def __init__(self, message):
+        self.message = message
