@@ -51,14 +51,20 @@ class CopyService(Service, ActionProvider):
         def on_clipboard_owner_change(self, clipboard, event):
             view = self.diagrams.get_current_view()
             if view and not view.is_focus():
-                global copy_buffer
-                copy_buffer = set()
+                self.clear()
 
     def copy(self, items):
         global copy_buffer
         if items:
             copy_buffer = copy(items)
 
+    def can_paste(self):
+        return bool(copy_buffer)
+
+    def clear(self):
+        global copy_buffer
+        copy_buffer = set()
+
     def paste_link(self, diagram):
         """Paste items in the copy-buffer to the diagram."""
         with Transaction(self.event_manager):
