@@ -17,6 +17,7 @@ from gaphor.core.modeling.element import Element
 from gaphor.core.modeling.presentation import Presentation
 from gaphor.core.modeling.stylesheet import StyleSheet
 from gaphor.storage import parser
+from gaphor.storage.xmlwriter import XMLWriter
 
 FILE_FORMAT_VERSION = "3.0"
 NAMESPACE_MODEL = "http://gaphor.sourceforge.net/model"
@@ -24,16 +25,17 @@ NAMESPACE_MODEL = "http://gaphor.sourceforge.net/model"
 log = logging.getLogger(__name__)
 
 
-def save(writer=None, factory=None, status_queue=None):
-    for status in save_generator(writer, factory):
+def save(out=None, factory=None, status_queue=None):
+    for status in save_generator(out, factory):
         if status_queue:
             status_queue(status)
 
 
-def save_generator(writer, factory):
+def save_generator(out, factory):
     """Save the current model using @writer, which is a
     gaphor.storage.xmlwriter.XMLWriter instance."""
 
+    writer = XMLWriter(out)
     writer.startDocument()
     writer.startPrefixMapping("", NAMESPACE_MODEL)
     writer.startElementNS(
@@ -174,9 +176,11 @@ def _load_elements_and_canvasitems(
             elem = upgrade_diagram_element(elem)
         if version_lower_than(gaphor_version, (2, 6, 0)):
             elem = upgrade_generalization_arrow_direction(elem)
+        if version_lower_than(gaphor_version, (2, 9, 0)):
+            elem = upgrade_flow_item_to_control_flow_item(elem, elements)
 
         cls = modeling_language.lookup_element(elem.type)
-        assert cls, f"Type {elem.type} can not be loaded: no such element"
+        assert cls, f"Type {elem.type} cannot be loaded: no such element"
         if issubclass(cls, Presentation):
             diagram_id = elem.references["diagram"]
             diagram_elem = elements[diagram_id]
@@ -376,3 +380,15 @@ def upgrade_generalization_arrow_direction(elem):
                 head_ids,
             )
     return elem
+
+
+# since 2.9.0
+def upgrade_flow_item_to_control_flow_item(elem, elements):
+    if elem.type == "FlowItem":
+        if subject_id := elem.references.get("subject"):
+            subject_type = elements[subject_id].type
+        else:
+            subject_type = "ControlFlow"
+
+        elem.type = f"{subject_type}Item"
+    return elem
