@@ -7,6 +7,7 @@ import sys
 from pathlib import Path
 from typing import Optional
 
+import darkdetect
 import gi
 
 if os.getenv("GAPHOR_USE_GTK") != "NONE":
@@ -14,16 +15,6 @@ if os.getenv("GAPHOR_USE_GTK") != "NONE":
     gtk_version = "4.0" if os.getenv("GAPHOR_USE_GTK") == "4" else "3.0"
     gtk_source_version = "5" if os.getenv("GAPHOR_USE_GTK") == "4" else "4"
 
-    if gtk_version == "4.0":
-        # Monkey patch PyGObject
-        import gi.overrides.Gtk
-
-        del gi.overrides.Gtk.TreeView.enable_model_drag_source
-        del gi.overrides.Gtk.TreeView.enable_model_drag_dest
-        gi.overrides.Gtk.ListStore.insert_with_valuesv = (
-            gi.overrides.Gtk.ListStore.insert_with_values
-        )
-
     gi.require_version("Gtk", gtk_version)
     gi.require_version("Gdk", gtk_version)
     if gtk_version == "3.0":
@@ -68,6 +59,12 @@ def main(argv=sys.argv):
     else:
         logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
 
+    # Set dark mode for non-FreeDesktop platforms only:
+    if sys.platform in ("darwin", "win32"):
+        Gtk.Settings.get_default().set_property(
+            "gtk-application-prefer-dark-theme", darkdetect.isDark()
+        )
+
     if has_option("-p", "--profiler"):
 
         import cProfile
