@@ -61,7 +61,7 @@ class ElementEditor(UIComponent, ActionProvider):
         """
         self.properties = properties
         self.editors = EditorStack(event_manager, diagrams, properties)
-        self.settings = SettingsStack(event_manager, element_factory)
+        self.preferences = PreferencesStack(event_manager, element_factory)
 
     def open(self):
         """Display the ElementEditor pane."""
@@ -72,7 +72,7 @@ class ElementEditor(UIComponent, ActionProvider):
         self.editor_stack = builder.get_object("editor-stack")
 
         self.editors.open(builder)
-        self.settings.open(builder)
+        self.preferences.open(builder)
 
         return self.revealer
 
@@ -84,33 +84,41 @@ class ElementEditor(UIComponent, ActionProvider):
         """
 
         self.editors.close()
-        self.settings.close()
+        self.preferences.close()
 
         return True
 
     @action(
         name="show-editors",
         shortcut="<Primary>e",
-        state=lambda self: self.properties.get("show-editors", True),
+        state=lambda self: self.properties.get("show-editors", True),  # type: ignore[no-any-return]
     )
     def toggle_editor_visibility(self, active):
         self.revealer.set_reveal_child(active)
         self.properties.set("show-editors", active)
 
-    @action(name="show-settings", state=False)
-    def toggle_editor_settings(self, active):
-        self.editor_stack.set_visible_child_name("settings" if active else "editors")
+    @action(name="show-preferences", shortcut="<Primary>comma", state=False)
+    def toggle_editor_preferences(self, active):
+        if not self.revealer.get_child_revealed():
+            if Gtk.get_major_version() == 3:
+                self.revealer.get_action_group("win").lookup_action(
+                    "show-editors"
+                ).activate()
+            else:
+                self.revealer.activate_action("win.show-editors", None)
+
+        self.editor_stack.set_visible_child_name("preferences" if active else "editors")
 
     @action(
         name="reset-tool-after-create",
-        state=lambda self: self.properties.get("reset-tool-after-create", True),
+        state=lambda self: self.properties.get("reset-tool-after-create", True),  # type: ignore[no-any-return]
     )
     def reset_tool_after_create(self, active):
         self.properties.set("reset-tool-after-create", active)
 
     @action(
         name="remove-unused-elements",
-        state=lambda self: self.properties.get("remove-unused-elements", True),
+        state=lambda self: self.properties.get("remove-unused-elements", True),  # type: ignore[no-any-return]
     )
     def remove_unused_elements(self, active):
         self.properties.set("remove-unused-elements", active)
@@ -175,7 +183,7 @@ class EditorStack:
                     self.vbox.append(page)
             except Exception:
                 log.error(
-                    "Could not construct property page for " + name, exc_info=True
+                    f"Could not construct property page for {name}", exc_info=True
                 )
 
     def clear_pages(self):
@@ -185,10 +193,8 @@ class EditorStack:
             for page in self.vbox.get_children():
                 page.destroy()
         else:
-            page = self.vbox.get_first_child()
-            while page:
+            while page := self.vbox.get_first_child():
                 self.vbox.remove(page)
-                page = self.vbox.get_first_child()
 
     def on_expand(self, widget, name):
         self._expanded_pages[name] = widget.get_expanded()
@@ -252,8 +258,8 @@ class EditorStack:
                 self.create_pages(self._current_item)
 
 
-class SettingsStack:
-    """Support code for the Settings (cog) pane."""
+class PreferencesStack:
+    """Support code for the Preferences (cog) pane."""
 
     def __init__(self, event_manager, element_factory):
         self.event_manager = event_manager
