@@ -4,11 +4,10 @@ import importlib.resources
 import logging
 from pathlib import Path
 
-from gi.repository import Gdk, Gio, GLib, Gtk
+from gi.repository import Gio, GLib, Gtk
 
 from gaphor.abc import ActionProvider, Service
 from gaphor.core import event_handler, gettext
-from gaphor.core.modeling import Diagram, ModelReady
 from gaphor.event import (
     ActionEnabled,
     ActiveSessionChanged,
@@ -20,12 +19,11 @@ from gaphor.event import (
 from gaphor.i18n import translated_ui_string
 from gaphor.services.modelinglanguage import ModelingLanguageChanged
 from gaphor.services.undomanager import UndoManagerStateChanged
+from gaphor.ui import HOME
 from gaphor.ui.abc import UIComponent
 from gaphor.ui.actiongroup import window_action_group
-from gaphor.ui.event import DiagramOpened
 from gaphor.ui.layout import deserialize, is_maximized
 from gaphor.ui.notification import InAppNotifier
-from gaphor.ui.recentfiles import HOME, RecentFilesMenu
 
 log = logging.getLogger(__name__)
 
@@ -41,12 +39,14 @@ def create_hamburger_model(export_menu, tools_menu):
     model = Gio.Menu.new()
 
     part = Gio.Menu.new()
-    part.append(gettext("New Window"), "app.file-new")
+    part.append(gettext("Open a Model…"), "app.file-open")
+    part.append(gettext("Recent Models…"), "app.recent-files")
+    part.append(gettext("New Model…"), "app.new-model")
     model.append_section(None, part)
 
     part = Gio.Menu.new()
     part.append(gettext("Save"), "win.file-save")
-    part.append(gettext("Save As..."), "win.file-save-as")
+    part.append(gettext("Save As…"), "win.file-save-as")
     part.append_submenu(gettext("Export"), export_menu)
     model.append_section(None, part)
 
@@ -62,15 +62,6 @@ def create_hamburger_model(export_menu, tools_menu):
     return model
 
 
-def create_recent_files_model(recent_manager=None):
-    model = Gio.Menu.new()
-    model.append_section(
-        gettext("Recently opened files"),
-        RecentFilesMenu(recent_manager or Gtk.RecentManager.get_default()),
-    )
-    return model
-
-
 def create_modeling_language_model(modeling_language):
     model = Gio.Menu.new()
     for id, name in modeling_language.modeling_languages:
@@ -80,6 +71,32 @@ def create_modeling_language_model(modeling_language):
     return model
 
 
+def create_diagram_types_model(modeling_language):
+    model = Gio.Menu.new()
+
+    part = Gio.Menu.new()
+    for id, name, _ in modeling_language.diagram_types:
+        menu_item = Gio.MenuItem.new(name, "win.create-diagram")
+        menu_item.set_attribute_value("target", GLib.Variant.new_string(id))
+        part.append_item(menu_item)
+    model.append_section(None, part)
+
+    part = Gio.Menu.new()
+    menu_item = Gio.MenuItem.new(gettext("New Generic Diagram"), "win.create-diagram")
+    menu_item.set_attribute_value("target", GLib.Variant.new_string(""))
+    part.append_item(menu_item)
+    model.append_section(None, part)
+
+    return model
+
+
+def popup_set_model(popup, model):
+    if Gtk.get_major_version() == 3:
+        popup.bind_model(model, None)
+    else:
+        popup.set_menu_model(model)
+
+
 class MainWindow(Service, ActionProvider):
     """The main window for the application.
 
@@ -92,7 +109,6 @@ class MainWindow(Service, ActionProvider):
         self,
         event_manager,
         component_registry,
-        element_factory,
         properties,
         modeling_language,
         export_menu,
@@ -100,7 +116,6 @@ class MainWindow(Service, ActionProvider):
     ):
         self.event_manager = event_manager
         self.component_registry = component_registry
-        self.element_factory = element_factory
         self.properties = properties
         self.modeling_language = modeling_language
         self.export_menu = export_menu
@@ -113,36 +128,17 @@ class MainWindow(Service, ActionProvider):
         self.model_changed = False
         self.layout = None
         self.modeling_language_name = None
+        self.diagram_types = None
         self.in_app_notifier = None
 
         event_manager.subscribe(self._on_file_manager_state_changed)
 
-        self.init_styling()
-
-    def init_styling(self):
-        with importlib.resources.path("gaphor.ui", "layout.css") as css_file:
-            style_provider = Gtk.CssProvider()
-            style_provider.load_from_path(str(css_file))
-            if Gtk.get_major_version() == 3:
-                Gtk.StyleContext.add_provider_for_screen(
-                    Gdk.Screen.get_default(),
-                    style_provider,
-                    Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION,
-                )
-            else:
-                Gtk.StyleContext.add_provider_for_display(
-                    Gdk.Display.get_default(),
-                    style_provider,
-                    Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION,
-                )
-
     def shutdown(self):
         if self.window:
             self.window.destroy()
             self.window = None
 
         em = self.event_manager
-        em.unsubscribe(self._on_model_ready)
         em.unsubscribe(self._on_file_manager_state_changed)
         em.unsubscribe(self._on_undo_manager_state_changed)
         em.unsubscribe(self._on_action_enabled)
@@ -162,32 +158,22 @@ class MainWindow(Service, ActionProvider):
         self.window.set_application(gtk_app)
 
         select_modeling_language = builder.get_object("select-modeling-language")
-        if Gtk.get_major_version() == 3:
-            select_modeling_language.bind_model(
-                create_modeling_language_model(self.modeling_language), None
-            )
-        else:
-            select_modeling_language.set_menu_model(
-                create_modeling_language_model(self.modeling_language)
-            )
+        popup_set_model(
+            select_modeling_language,
+            create_modeling_language_model(self.modeling_language),
+        )
         self.modeling_language_name = builder.get_object("modeling-language-name")
 
-        hamburger = builder.get_object("hamburger")
-        if Gtk.get_major_version() == 3:
-            hamburger.bind_model(
-                create_hamburger_model(self.export_menu.menu, self.tools_menu.menu),
-                None,
-            )
-        else:
-            hamburger.set_menu_model(
-                create_hamburger_model(self.export_menu.menu, self.tools_menu.menu)
-            )
+        self.diagram_types = builder.get_object("diagram-types")
+        popup_set_model(
+            self.diagram_types, create_diagram_types_model(self.modeling_language)
+        )
 
-        recent_files = builder.get_object("recent-files")
-        if Gtk.get_major_version() == 3:
-            recent_files.bind_model(create_recent_files_model(), None)
-        else:
-            recent_files.set_menu_model(create_recent_files_model())
+        hamburger = builder.get_object("hamburger")
+        popup_set_model(
+            hamburger,
+            create_hamburger_model(self.export_menu.menu, self.tools_menu.menu),
+        )
 
         self.title = builder.get_object("title")
         self.subtitle = builder.get_object("subtitle")
@@ -226,18 +212,11 @@ class MainWindow(Service, ActionProvider):
 
         self.in_app_notifier = InAppNotifier(builder)
         em = self.event_manager
-        em.subscribe(self._on_model_ready)
         em.subscribe(self._on_undo_manager_state_changed)
         em.subscribe(self._on_action_enabled)
         em.subscribe(self._on_modeling_language_selection_changed)
         em.subscribe(self.in_app_notifier.handle)
 
-        self._on_model_ready()
-
-    def open_welcome_page(self):
-        """Create a new tab with a textual welcome page, a sort of 101 for
-        Gaphor."""
-
     def set_title(self):
         """Sets the window title."""
         if not self.window:
@@ -245,8 +224,8 @@ class MainWindow(Service, ActionProvider):
 
         if self.filename:
             p = Path(self.filename)
-            title = p.name
-            subtitle = str(p.parent).replace(HOME, "~")
+            title = p.stem
+            subtitle = str(p).replace(HOME, "~")
         else:
             title = "Gaphor"
             subtitle = gettext("New model")
@@ -258,19 +237,6 @@ class MainWindow(Service, ActionProvider):
 
     # Signal callbacks:
 
-    @event_handler(ModelReady)
-    def _on_model_ready(self, event=None):
-        """Open the toplevel element and load toplevel diagrams."""
-        diagram_ids = self.properties.get("opened-diagrams", [])
-        diagrams = [self.element_factory.lookup(id) for id in diagram_ids]
-        if not any(diagrams):
-            diagrams = self.element_factory.select(
-                lambda e: e.isKindOf(Diagram) and not (e.owner and e.owner.owner)
-            )
-        for diagram in diagrams:
-            if diagram:
-                self.event_manager.handle(DiagramOpened(diagram))
-
     @event_handler(SessionCreated, ModelLoaded, ModelSaved)
     def _on_file_manager_state_changed(self, event):
         self.model_changed = False
@@ -300,9 +266,11 @@ class MainWindow(Service, ActionProvider):
     def _on_modeling_language_selection_changed(self, event=None):
         if self.modeling_language_name:
             self.modeling_language_name.set_label(
-                gettext("Profile: {}").format(
-                    self.modeling_language.active_modeling_language_name
-                )
+                gettext("Profile: {}").format(self.modeling_language.name)
+            )
+        if self.diagram_types:
+            popup_set_model(
+                self.diagram_types, create_diagram_types_model(self.modeling_language)
             )
 
     def _on_window_active(self, window, prop):
