@@ -10,6 +10,7 @@ from __future__ import annotations
 import logging
 from typing import TYPE_CHECKING
 
+from gaphas.decorators import g_async
 from gi.repository import Gdk, Gio, GLib, Gtk
 
 from gaphor import UML
@@ -62,8 +63,7 @@ def popup_model(element, modeling_language):
 
     part = Gio.Menu.new()
     for presentation in element.presentation:
-        diagram = presentation.diagram
-        if diagram:
+        if diagram := presentation.diagram:
             menu_item = Gio.MenuItem.new(
                 gettext("Show in “{diagram}”").format(diagram=diagram.name),
                 "tree-view.show-in-diagram",
@@ -120,30 +120,35 @@ class Namespace(UIComponent, ActionProvider):
         scrolled_window.insert_action_group("tree-view", action_group)
 
         if Gtk.get_major_version() == 3:
-            ctrl = Gtk.GestureMultiPress.new(view)
-            ctrl.set_button(Gdk.BUTTON_SECONDARY)
-            ctrl.connect("pressed", self._on_show_popup)
-            self.ctrl.add(ctrl)
-
-            ctrl = Gtk.EventControllerKey.new(view)
-            ctrl.connect("key-pressed", self._on_edit_pressed)
-            self.ctrl.add(ctrl)
+            self.create_gtk3_popup_controller(view)
         else:
-            ctrl = Gtk.ShortcutController.new_for_model(shortcuts)
-            ctrl.set_scope(Gtk.ShortcutScope.LOCAL)
-            view.add_controller(ctrl)
-
-            ctrl = Gtk.GestureClick.new()
-            ctrl.set_button(Gdk.BUTTON_SECONDARY)
-            ctrl.connect("pressed", self._on_show_popup)
-            view.add_controller(ctrl)
-
+            self.create_gtk4_popup_controller(shortcuts, view)
         self.view = view
         self.scrolled_window = scrolled_window
         self.model.refresh()
 
         return scrolled_window
 
+    def create_gtk4_popup_controller(self, shortcuts, view):
+        ctrl = Gtk.ShortcutController.new_for_model(shortcuts)
+        ctrl.set_scope(Gtk.ShortcutScope.LOCAL)
+        view.add_controller(ctrl)
+
+        ctrl = Gtk.GestureClick.new()
+        ctrl.set_button(Gdk.BUTTON_SECONDARY)
+        ctrl.connect("pressed", self._on_show_popup)
+        view.add_controller(ctrl)
+
+    def create_gtk3_popup_controller(self, view):
+        ctrl = Gtk.GestureMultiPress.new(view)
+        ctrl.set_button(Gdk.BUTTON_SECONDARY)
+        ctrl.connect("pressed", self._on_show_popup)
+        self.ctrl.add(ctrl)
+
+        ctrl = Gtk.EventControllerKey.new(view)
+        ctrl.connect("key-pressed", self._on_edit_pressed)
+        self.ctrl.add(ctrl)
+
     def close(self):
         self.ctrl.clear()
         if self.view:
@@ -254,18 +259,18 @@ class Namespace(UIComponent, ActionProvider):
             parent_path = Gtk.TreePath.new_from_indices(path_indices[:-1])
             self.view.expand_row(path=parent_path, open_all=False)
 
-        selection = self.view.get_selection()
-        selection.select_path(path)
+        self.view.set_cursor(path, self.view.get_column(0), False)
         self.view.scroll_to_cell(path, None, False, 0, 0)
         self._on_view_cursor_changed(self.view)
 
     def get_selected_element(self) -> Element | None:
         assert self.view
-        selection = self.view.get_selection()
-        model, iter = selection.get_selected()
-        if not iter:
+        assert self.model
+        path, _column = self.view.get_cursor()
+        if not path:
             return None
-        return model.get_value(iter, 0)  # type: ignore[no-any-return]
+        model = self.model
+        return model.get_value(model.get_iter(path), 0)  # type: ignore[no-any-return]
 
     @action(name="tree-view.open")
     def tree_view_open_selected(self):
@@ -281,15 +286,13 @@ class Namespace(UIComponent, ActionProvider):
         self.event_manager.handle(DiagramOpened(element))
 
     @action(name="tree-view.rename", shortcut="F2")
+    @g_async(single=True)
     def tree_view_rename_selected(self):
         assert self.view
         view = self.view
         element = self.get_selected_element()
-        if element not in (None, RELATIONSHIPS):
-            selection = view.get_selection()
-            model, iter = selection.get_selected()
-            path = model.get_path(iter)
-            column = view.get_column(0)
+        path, column = view.get_cursor()
+        if path and column and element not in (None, RELATIONSHIPS):
             cell = column.get_cells()[1]
             cell.set_property("editable", 1)
             view.set_cursor(path, column, True)
@@ -329,8 +332,7 @@ class Namespace(UIComponent, ActionProvider):
 
     @action(name="tree-view.delete")
     def tree_view_delete(self):
-        element = self.get_selected_element()
-        if element:
+        if element := self.get_selected_element():
             with Transaction(self.event_manager):
                 element.unlink()
 
