@@ -7,7 +7,7 @@ from gaphas.decorators import g_async
 from gi.repository import Gtk
 
 from gaphor import UML
-from gaphor.core import Transaction, event_handler, gettext
+from gaphor.core import Transaction, event_handler
 from gaphor.core.format import format
 from gaphor.core.modeling import (
     AttributeUpdated,
@@ -18,7 +18,7 @@ from gaphor.core.modeling import (
     ModelFlushed,
     ModelReady,
 )
-from gaphor.event import Notification
+from gaphor.diagram.group import can_group, group, ungroup
 
 if TYPE_CHECKING:
     from gaphor.core.eventmanager import EventManager
@@ -117,6 +117,23 @@ class NamespaceModel(Gtk.TreeStore):
             child_iter = self.iter_next(child_iter)
         return None
 
+    def element_for_path(self, path):
+        if not path:
+            return None
+
+        try:
+            iter = self.get_iter(path)
+        except ValueError:
+            log.debug(f"Invalid path: '{path}'")
+            return None
+
+        element = self.get_value(iter, 0)
+
+        if element is RELATIONSHIPS:
+            iter = relationship_iter_parent(self, iter)
+            element = self.get_value(iter, 0)
+        return element
+
     def _visible(self, element):
         return isinstance(
             element, (UML.Relationship, UML.NamedElement, Diagram)
@@ -203,8 +220,7 @@ class NamespaceModel(Gtk.TreeStore):
         ):
             element = event.element
 
-            iter = self.iter_for_element(element)
-            if iter:
+            if iter := self.iter_for_element(element):
                 path = self.get_path(iter)
                 self.row_changed(path, iter)
                 self.sort()
@@ -244,8 +260,11 @@ class NamespaceModel(Gtk.TreeStore):
 
         src_row = self[src_path]
         element = src_row[0]
+        parent_path = Gtk.TreePath.copy(dest_path)
+        parent_path.up()
+        dest_element = self.element_for_path(parent_path)
 
-        return isinstance(element, (Diagram, UML.Package, UML.Type))
+        return dest_element is None or can_group(dest_element, element)
 
     def do_drag_data_received(self, dest_path, selection_data):
         if str(selection_data.get_target()) != "GTK_TREE_MODEL_ROW":
@@ -257,63 +276,43 @@ class NamespaceModel(Gtk.TreeStore):
             log.debug("Can't DnD from different tree model")
             return False
 
-        src_row = self[src_path]
-        element = src_row[0]
-
-        dest_path.up()
-        if not dest_path:
-            dest_element = None
-        else:
-            try:
-                iter = self.get_iter(dest_path)
-            except ValueError:
-                log.debug(f"Invalid path: '{dest_path}'")
-                return False
-
-            dest_element = self.get_value(iter, 0)
-
-            if dest_element is RELATIONSHIPS:
-                iter = relationship_iter_parent(self, iter)
-                dest_element = self.get_value(iter, 0)
-
-            if element.owner is dest_element:
-                return False
-
-            # Check if element is part of the namespace of dest_element:
-            ns = dest_element
-            while ns:
-                if ns is element:
-                    log.info("Can not create a cycle")
-                    return False
-                ns = ns.owner
+        element = self[src_path][0]
+        parent_path = Gtk.TreePath.copy(dest_path)
+        parent_path.up()
+        dest_element = self.element_for_path(parent_path)
 
         try:
-            # Set package. This only works for classifiers, packages and
-            # diagrams. Properties and operations should not be moved.
-            with Transaction(self.event_manager):
-                if dest_element is None and isinstance(element, Diagram):
-                    del element.element
-                elif dest_element is None:
-                    del element.package
-                elif isinstance(element, Diagram):
-                    element.element = dest_element
+            with Transaction(self.event_manager) as tx:
+
+                # This view is concerned with owner relationships.
+                # Let's check if the owner relation has actually changed,
+                # Otherwise roll back, to not confuse the user.
+                if not change_owner(dest_element, element):
+                    tx.rollback()
                 else:
-                    element.package = dest_element
-                self.event_manager.handle(NamespaceModelElementDropped(self, element))
-            return True
-        except (AttributeError, TypeError) as e:
-            self.namespace_exception(dest_element, e, element)
+                    return True
+        finally:
+            self.event_manager.handle(NamespaceModelElementDropped(self, element))
+
         return False
 
-    def namespace_exception(self, dest_element, e, element):
-        log.info(f"Unable to drop data {e}")
-        self.event_manager.handle(
-            Notification(
-                gettext("A {} can’t be part of a {}.").format(
-                    type(element).__name__, type(dest_element).__name__
-                )
-            )
-        )
+
+def change_owner(new_parent, element):
+    if element.owner is new_parent:
+        return False
+
+    if new_parent is None and element.owner:
+        return ungroup(element.owner, element)
+
+    if not can_group(new_parent, element):
+        return False
+
+    if element.owner:
+        ungroup(element.owner, element)
+
+    group(new_parent, element)
+
+    return element.owner is new_parent
 
 
 def sort_func(model, iter_a, iter_b, userdata):
